package com.ruoyi.web.controller.rc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TAudit;
import com.ruoyi.rc.service.ITAuditService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 审计记录Controller
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/rc/audit")
public class TAuditController extends BaseController
{
    @Autowired
    private ITAuditService tAuditService;

    /**
     * 查询审计记录列表
     */
    @PreAuthorize("@ss.hasPermi('rc:audit:list')")
    @GetMapping("/list")
    public TableDataInfo list(TAudit tAudit)
    {
        startPage();
        List<TAudit> list = tAuditService.selectTAuditList(tAudit);
        return getDataTable(list);
    }

    /**
     * 导出审计记录列表
     */
    @PreAuthorize("@ss.hasPermi('rc:audit:export')")
    @Log(title = "审计记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TAudit tAudit)
    {
        List<TAudit> list = tAuditService.selectTAuditList(tAudit);
        ExcelUtil<TAudit> util = new ExcelUtil<TAudit>(TAudit.class);
        util.exportExcel(response, list, "审计记录数据");
    }

    /**
     * 获取审计记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:audit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tAuditService.selectTAuditById(id));
    }

    /**
     * 新增审计记录
     */
    @PreAuthorize("@ss.hasPermi('rc:audit:add')")
    @Log(title = "审计记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TAudit tAudit)
    {
        if (StringUtils.isNull(tAudit.getDeptId())) {
            tAudit.setDeptId(getLoginUser().getDeptId());
        }
        return toAjax(tAuditService.insertTAudit(tAudit));
    }

    /**
     * 修改审计记录
     */
    @PreAuthorize("@ss.hasPermi('rc:audit:edit')")
    @Log(title = "审计记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TAudit tAudit)
    {
        return toAjax(tAuditService.updateTAudit(tAudit));
    }

    /**
     * 删除审计记录
     */
    @PreAuthorize("@ss.hasPermi('rc:audit:remove')")
    @Log(title = "审计记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tAuditService.deleteTAuditByIds(ids));
    }
}
