package com.ruoyi.web.controller.rc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TChap;
import com.ruoyi.rc.service.ITChapService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 问卷章节Controller
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/rc/chap")
public class TChapController extends BaseController
{
    @Autowired
    private ITChapService tChapService;

    /**
     * 查询问卷章节列表
     */
    @PreAuthorize("@ss.hasPermi('rc:chap:list')")
    @GetMapping("/list")
    public TableDataInfo list(TChap tChap)
    {
        startPage();
        List<TChap> list = tChapService.selectTChapList(tChap);
        return getDataTable(list);
    }

    /**
     * 导出问卷章节列表
     */
    @PreAuthorize("@ss.hasPermi('rc:chap:export')")
    @Log(title = "问卷章节", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TChap tChap)
    {
        List<TChap> list = tChapService.selectTChapList(tChap);
        ExcelUtil<TChap> util = new ExcelUtil<TChap>(TChap.class);
        util.exportExcel(response, list, "问卷章节数据");
    }

    /**
     * 获取问卷章节详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:chap:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tChapService.selectTChapById(id));
    }

    /**
     * 新增问卷章节
     */
    @PreAuthorize("@ss.hasPermi('rc:chap:add')")
    @Log(title = "问卷章节", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TChap tChap)
    {
        tChap.setDeptId(getLoginUser().getDeptId());
        return toAjax(tChapService.insertTChap(tChap));
    }

    /**
     * 修改问卷章节
     */
    @PreAuthorize("@ss.hasPermi('rc:chap:edit')")
    @Log(title = "问卷章节", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TChap tChap)
    {
        return toAjax(tChapService.updateTChap(tChap));
    }

    /**
     * 删除问卷章节
     */
    @PreAuthorize("@ss.hasPermi('rc:chap:remove')")
    @Log(title = "问卷章节", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tChapService.deleteTChapByIds(ids));
    }
}
