package com.ruoyi.web.controller.rc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TDeptInfo;
import com.ruoyi.rc.service.ITDeptInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.StringUtils;

/**
 * 装置信息Controller
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/rc/deptinfo")
public class TDeptInfoController extends BaseController
{
    @Autowired
    private ITDeptInfoService tDeptInfoService;

    /**
     * 查询装置信息列表
     */
    @PreAuthorize("@ss.hasPermi('rc:deptinfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(TDeptInfo tDeptInfo)
    {
        startPage();
        List<TDeptInfo> list = tDeptInfoService.selectTDeptInfoList(tDeptInfo);
        return getDataTable(list);
    }

    /**
     * 导出装置信息列表
     */
    @PreAuthorize("@ss.hasPermi('rc:deptinfo:export')")
    @Log(title = "装置信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TDeptInfo tDeptInfo)
    {
        List<TDeptInfo> list = tDeptInfoService.selectTDeptInfoList(tDeptInfo);
        ExcelUtil<TDeptInfo> util = new ExcelUtil<TDeptInfo>(TDeptInfo.class);
        util.exportExcel(response, list, "装置信息数据");
    }

    /**
     * 获取装置信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:deptinfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tDeptInfoService.selectTDeptInfoById(id));
    }

    /**
     * 新增装置信息
     */
    @PreAuthorize("@ss.hasPermi('rc:deptinfo:add')")
    @Log(title = "装置信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TDeptInfo tDeptInfo)
    {
        if (StringUtils.isNull(tDeptInfo.getDeptId())) {
            tDeptInfo.setDeptId(getLoginUser().getDeptId());
        }
        return toAjax(tDeptInfoService.insertTDeptInfo(tDeptInfo));
    }

    /**
     * 修改装置信息
     */
    @PreAuthorize("@ss.hasPermi('rc:deptinfo:edit')")
    @Log(title = "装置信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TDeptInfo tDeptInfo)
    {
        return toAjax(tDeptInfoService.updateTDeptInfo(tDeptInfo));
    }

    /**
     * 删除装置信息
     */
    @PreAuthorize("@ss.hasPermi('rc:deptinfo:remove')")
    @Log(title = "装置信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tDeptInfoService.deleteTDeptInfoByIds(ids));
    }
}
