package com.ruoyi.web.controller.rc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TMeeting;
import com.ruoyi.rc.service.ITMeetingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 会议Controller
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/rc/meeting")
public class TMeetingController extends BaseController
{
    @Autowired
    private ITMeetingService tMeetingService;

    /**
     * 查询会议列表
     */
    @PreAuthorize("@ss.hasPermi('rc:meeting:list')")
    @GetMapping("/list")
    public TableDataInfo list(TMeeting tMeeting)
    {
        startPage();
        List<TMeeting> list = tMeetingService.selectTMeetingList(tMeeting);
        return getDataTable(list);
    }

    /**
     * 导出会议列表
     */
    @PreAuthorize("@ss.hasPermi('rc:meeting:export')")
    @Log(title = "会议", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TMeeting tMeeting)
    {
        List<TMeeting> list = tMeetingService.selectTMeetingList(tMeeting);
        ExcelUtil<TMeeting> util = new ExcelUtil<TMeeting>(TMeeting.class);
        util.exportExcel(response, list, "会议数据");
    }

    /**
     * 获取会议详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:meeting:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tMeetingService.selectTMeetingById(id));
    }

    /**
     * 新增会议
     */
    @PreAuthorize("@ss.hasPermi('rc:meeting:add')")
    @Log(title = "会议", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TMeeting tMeeting)
    {
        tMeeting.setDeptId(getLoginUser().getDeptId());
        return toAjax(tMeetingService.insertTMeeting(tMeeting));
    }

    /**
     * 修改会议
     */
    @PreAuthorize("@ss.hasPermi('rc:meeting:edit')")
    @Log(title = "会议", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TMeeting tMeeting)
    {
        return toAjax(tMeetingService.updateTMeeting(tMeeting));
    }

    /**
     * 删除会议
     */
    @PreAuthorize("@ss.hasPermi('rc:meeting:remove')")
    @Log(title = "会议", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tMeetingService.deleteTMeetingByIds(ids));
    }
}
