package com.ruoyi.web.controller.rc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TSecSubChap;
import com.ruoyi.rc.service.ITSecSubChapService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 问卷二级细分章节Controller
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/rc/secsubchap")
public class TSecSubChapController extends BaseController
{
    @Autowired
    private ITSecSubChapService tSecSubChapService;

    /**
     * 查询问卷二级细分章节列表
     */
    @PreAuthorize("@ss.hasPermi('rc:secsubchap:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSecSubChap tSecSubChap)
    {
        startPage();
        List<TSecSubChap> list = tSecSubChapService.selectTSecSubChapList(tSecSubChap);
        return getDataTable(list);
    }

    /**
     * 导出问卷二级细分章节列表
     */
    @PreAuthorize("@ss.hasPermi('rc:secsubchap:export')")
    @Log(title = "问卷二级细分章节", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSecSubChap tSecSubChap)
    {
        List<TSecSubChap> list = tSecSubChapService.selectTSecSubChapList(tSecSubChap);
        ExcelUtil<TSecSubChap> util = new ExcelUtil<TSecSubChap>(TSecSubChap.class);
        util.exportExcel(response, list, "问卷二级细分章节数据");
    }

    /**
     * 获取问卷二级细分章节详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:secsubchap:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tSecSubChapService.selectTSecSubChapById(id));
    }

    /**
     * 新增问卷二级细分章节
     */
    @PreAuthorize("@ss.hasPermi('rc:secsubchap:add')")
    @Log(title = "问卷二级细分章节", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSecSubChap tSecSubChap)
    {
        tSecSubChap.setDeptId(getLoginUser().getDeptId());
        return toAjax(tSecSubChapService.insertTSecSubChap(tSecSubChap));
    }

    /**
     * 修改问卷二级细分章节
     */
    @PreAuthorize("@ss.hasPermi('rc:secsubchap:edit')")
    @Log(title = "问卷二级细分章节", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSecSubChap tSecSubChap)
    {
        return toAjax(tSecSubChapService.updateTSecSubChap(tSecSubChap));
    }

    /**
     * 删除问卷二级细分章节
     */
    @PreAuthorize("@ss.hasPermi('rc:secsubchap:remove')")
    @Log(title = "问卷二级细分章节", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSecSubChapService.deleteTSecSubChapByIds(ids));
    }
}
