package com.ruoyi.web.controller.rc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.rc.domain.TSubChap;
import com.ruoyi.rc.service.ITSubChapService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 问卷细分章节Controller
 * 
 * @author ruoyi
 * @date 2024-07-19
 */
@RestController
@RequestMapping("/rc/subchap")
public class TSubChapController extends BaseController
{
    @Autowired
    private ITSubChapService tSubChapService;

    /**
     * 查询问卷细分章节列表
     */
    @PreAuthorize("@ss.hasPermi('rc:subchap:list')")
    @GetMapping("/list")
    public TableDataInfo list(TSubChap tSubChap)
    {
        startPage();
        List<TSubChap> list = tSubChapService.selectTSubChapList(tSubChap);
        return getDataTable(list);
    }

    /**
     * 导出问卷细分章节列表
     */
    @PreAuthorize("@ss.hasPermi('rc:subchap:export')")
    @Log(title = "问卷细分章节", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TSubChap tSubChap)
    {
        List<TSubChap> list = tSubChapService.selectTSubChapList(tSubChap);
        ExcelUtil<TSubChap> util = new ExcelUtil<TSubChap>(TSubChap.class);
        util.exportExcel(response, list, "问卷细分章节数据");
    }

    /**
     * 获取问卷细分章节详细信息
     */
    @PreAuthorize("@ss.hasPermi('rc:subchap:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tSubChapService.selectTSubChapById(id));
    }

    /**
     * 新增问卷细分章节
     */
    @PreAuthorize("@ss.hasPermi('rc:subchap:add')")
    @Log(title = "问卷细分章节", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TSubChap tSubChap)
    {
        tSubChap.setDeptId(getLoginUser().getDeptId());
        return toAjax(tSubChapService.insertTSubChap(tSubChap));
    }

    /**
     * 修改问卷细分章节
     */
    @PreAuthorize("@ss.hasPermi('rc:subchap:edit')")
    @Log(title = "问卷细分章节", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TSubChap tSubChap)
    {
        return toAjax(tSubChapService.updateTSubChap(tSubChap));
    }

    /**
     * 删除问卷细分章节
     */
    @PreAuthorize("@ss.hasPermi('rc:subchap:remove')")
    @Log(title = "问卷细分章节", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tSubChapService.deleteTSubChapByIds(ids));
    }
}
